@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2006 Red Hat, Inc.
+# Copyright (C) 2006-2010 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 import gettext
 translation=gettext.translation('setroubleshoot-plugins', fallback=True)
-_=translation.ugettext
+_=translation.gettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
@@ -28,7 +28,7 @@ class plugin(Plugin):
     SELinux is preventing $SOURCE_PATH from changing the access
     protection of memory on the heap.
     ''')
-    
+
     problem_description = _('''
     The $SOURCE application attempted to change the access protection of memory on
     the heap (e.g., allocated using malloc).  This is a potential security
@@ -46,19 +46,17 @@ class plugin(Plugin):
     $BOOLEAN boolean.  Note: This boolean will affect all applications
     on the system.
     ''')
-    
-    fix_cmd = "setsebool -P $BOOLEAN=1"
+
+    if_text = _("If you do not think $SOURCE_PATH should need to map heap memory that is both writable and executable.")
+    then_text = _("you need to report a bug. This is a potentially dangerous access.")
+    do_text = _("Contact your security administrator and report this issue.")
 
     def __init__(self):
         Plugin.__init__(self, __name__)
 
     def analyze(self, avc):
         if avc.has_any_access_in(['execheap']):
-            # MATCH
-            avc.set_template_substitutions(BOOLEAN="allow_execheap")
-            return self.report(avc, _("Memory"),
-                               self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+            return self.report()
         else:
             return None
 
