@@ -18,7 +18,7 @@
 
 import gettext
 translation=gettext.translation('setroubleshoot-plugins', fallback=True)
-_=translation.ugettext
+_=translation.gettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
@@ -43,20 +43,24 @@ class plugin(Plugin):
     You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t xen_image_t '$FIX_TARGET_PATH'"
     ''')
 
-    fix_cmd = "chcon -t xen_image_t '$TARGET_PATH'"
-    
+    fix_cmd = "/usr/bin/chcon -t xen_image_t '$TARGET_PATH'"
+
+    then_text = _("You need to change the label on '$FIX_TARGET_PATH'")
+
+    do_text = """# semanage fcontext -a -t xen_image_t '$FIX_TARGET_PATH'
+# restorecon -v '$FIX_TARGET_PATH'"""
+
     def __init__(self):
         Plugin.__init__(self, __name__)
+        self.fixable=True
+        self.button_text = _("Change the file label to xen_image_t.")
 
     def analyze(self, avc):
-        if avc.matches_source_types(['xend_t', 'xm_t'])                 and \
-           avc.all_accesses_are_in(avc.r_file_perms + avc.r_dir_perms)  and \
-           avc.has_tclass_in(['file', 'dir'])                           and \
-           avc.path_is_not_standard_directory():
+        if (avc.matches_source_types(['xend_t', 'virsh_t'])              and
+            avc.all_accesses_are_in(avc.r_file_perms + avc.r_dir_perms)  and
+            avc.has_tclass_in(['file', 'dir'])                           and
+            avc.path_is_not_standard_directory()):
             # MATCH
-            return self.report(avc, _("File Label"),
-                               self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+            return self.report()
         else:
             return None
-
